@@ -6,6 +6,17 @@ import numpy as np
 from ..core import plot_options as plotOptCore
 from ..core.serialization import register as serializationReg
 
+@serializationReg.registerForSerialization()
+class AspectString(plotOptCore.StringPlotOption):
+	""" String controlling how the image aspect works
+
+	equal: Pixels kept square; aspect ratio is maintained but axes may not fill the space
+	auto: Aspect ratio is altered such that the image fits the axes; may be useful when creating grids of images
+
+	"""
+	def __init__(self, name=None, value=None):
+		self.name = "aspectStr"
+		self.value = value
 
 @serializationReg.registerForSerialization()
 class AxisBorderMakeInvisible(plotOptCore.BoolNamespaceOption):
@@ -94,6 +105,17 @@ class BarColors(plotOptCore.StringIterPlotOption):
 		self.name = "barColors"
 		self.value = value
 
+@serializationReg.registerForSerialization()
+class BarOpacities(plotOptCore.FloatIterPlotOption):
+	""" The opacities to use for each bar. Values should be between 0 (invisible) and 1 (fully opaque). Corresponds to the alpha keyword in matplotlib.
+
+	Note: The number of values doesnt have to match the number of data series, if you provide too few values, they should cycle. For example setting [0.5,1.0] may lead to plotted opacities of [0.5, 1.0, 0.5, 1.0, .... etc]
+
+	"""
+	def __init__(self, name=None, value=None):
+		self.name = "barOpacities" if name is None else name
+		self.value = value
+
 @serializationReg.registerForSerialization()
 class ColorBarFontSize(plotOptCore.IntPlotOption):
 	""" The font size to use for the colorbar
