@@ -53,6 +53,7 @@ def _createCommandsList():
 	plotCmdStdHelp.GridLinesCreate(),
 	SetBarDataLabels(),
 	plotCmdStdHelp.SetBarColors(),
+	plotCmdStdHelp.SetBarOpacities(),
 	plotCmdStdHelp.SetXLabelStr(),
 	plotCmdStdHelp.SetYLabelStr(),
 	plotCmdStdHelp.SetTickLabelFontSize(),
@@ -82,6 +83,7 @@ def _createOptionsList():
 	plotOptStdHelp.AxisColorY(),
 	plotOptStdHelp.AxisColorY_exclSpines(),
 	plotOptStdHelp.BarColors(),
+	plotOptStdHelp.BarOpacities(),
 	plotOptStdHelp.DataLabels(),
 	plotOptStdHelp.FontSizeDefault(),
 	plotOptStdHelp.GridLinesShow(value=False),
