@@ -45,6 +45,7 @@ def _createCommandsList():
 	PlotHistoData(),
 	plotCmdStdHelp.SetBarDataLabels(),
 	plotCmdStdHelp.SetBarColors(),
+	plotCmdStdHelp.SetBarOpacities(),
 	plotCmdStdHelp.GridLinesCreate(),
 	plotCmdStdHelp.SetXLabelStr(),
 	plotCmdStdHelp.SetYLabelStr(),
@@ -83,6 +84,7 @@ def _createOptionsList():
 	plotOptStdHelp.AxisColorY(),
 	plotOptStdHelp.AxisColorY_exclSpines(),
 	plotOptStdHelp.BarColors(),
+	plotOptStdHelp.BarOpacities(),
 	plotOptStdHelp.DataLabels(),
 	plotOptStdHelp.FontSizeDefault(),
 	plotOptStdHelp.GridLinesShow(value=False),
